==> PalmLJ-src-1.1.0.tar.gz: PalmLJ-1.1.0/PalmLJ.h <==
/* PalmLJ.h     -- Structures that Palm LiveJournal uses
 * $Id: PalmLJ.h,v 1.2 2001/03/30 23:52:52 kvance Exp $
 * Copyright (C) 2000-2001 Kev Vance <kvance@tekktonik.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _PALMLJ_H
#define _PALMLJ_H 1

typedef struct AccessRecord {
    Char user[64];
    struct AccessRecord *next;
} AccessRecord;
typedef struct UserRecord {
    Char user[64];
    Char passwd[64];
    Char name[128];
    Int16 accessCount;
    struct AccessRecord *accessRecord;
    struct UserRecord *next;
} UserRecord;
typedef struct MoodRecord {
    UInt16 id;
    Char name[15];
    struct MoodRecord *next;
} MoodRecord;
typedef struct LJPrefs {
    UInt16 version;
    UInt16 userCount;
    UInt16 moodCount;
    UInt16 lastUser;
    UInt16 lastAccess;
    UInt16 connectType;
    UserRecord *userRecord;
    MoodRecord *moodRecord;
} LJPrefs;

enum connecttypes {
    Undecided, NetLib, INetLib, HotSync
};

extern UserRecord *GetUserRecord(UserRecord *, UInt16);
extern AccessRecord *GetAccessRecord(AccessRecord *, UInt16);

extern int Post(Char * user, Char * usejournal, Char * passwd, Char * subject,
		Char * entry, UInt16 mood, Char * custommood, UInt16 ct);
extern int Login(Char * user, Char * passwd, LJPrefs * prefs, Boolean moods,
		 Boolean new, UInt16 ct);

#endif				/* _PALMLJ_H */

==> PalmLJ-src-1.2.0.tar.gz: PalmLJ-1.2.0/PalmLJ.h <==
/* PalmLJ.h     -- Structures that Palm LiveJournal uses
 * $Id: PalmLJ.h,v 1.3 2001/04/15 19:31:10 kvance Exp $
 * Copyright (C) 2000-2001 Kev Vance <kvance@tekktonik.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _PALMLJ_H
#define _PALMLJ_H 1

#define idCreator	'PaLJ'
#define idDatabase	'LJdb'

typedef struct AccessRecord {
    Char user[64];
    struct AccessRecord *next;
} AccessRecord;
typedef struct UserRecord {	/* current version = 1 */
    Char user[64];
    Char passwd[32];
    Char name[128];
    Int16 accessCount;
    struct AccessRecord *accessRecord;
    struct UserRecord *next;
} UserRecord;
typedef struct MoodRecord {
    UInt16 id;
    Char name[15];
    struct MoodRecord *next;
} MoodRecord;
typedef struct LJPrefs {
    UInt16 version;	/* current version = 3 */
    UInt16 lastUser;
    UInt16 lastAccess;
    UInt16 connectType;
} LJPrefs;

typedef struct Entry {
	UInt16 version;	/* current version = 1 */
	DateTimeType date;
	UInt16 userLength; Char *user;
	UInt16 ujLength; Char *uj;
	UInt16 passwdLength; Char *passwd;
	UInt16 subjLength; Char *subject;
	UInt16 textLength; Char *text;
	UInt16 moodNumber;
	UInt16 moodLength; Char *mood;
} Entry;

enum connecttypes {
    Undecided, NetLib, INetLib, HotSync
};

extern UInt16 ljErr;
extern UInt16 userCount;
extern UserRecord *users;

extern UserRecord *GetUserRecord(UserRecord *, UInt16);
extern AccessRecord *GetAccessRecord(AccessRecord *, UInt16);

extern int Post(Entry *e, UInt16 ct);
extern int Login(Char * user, Char * passwd, LJPrefs * prefs, Boolean moods,
		 Boolean new, UInt16 ct);

extern Entry *CreateEntry(Char *user, Char *uj, Char *passwd, Char *subject,
		Char *text, UInt16 moodnumber, Char *mood, DateTimeType date);
extern void DeleteEntry(Entry *e);
extern int SaveEntry(Entry *e);

extern int SaveUsers(UserRecord *base);
extern UserRecord *GetUsers(void);

#endif				/* _PALMLJ_H */
